pub struct VariableInfo {
pub id: SourceVarId,
pub path: Vec<String>,
pub var_kind: VariableKind,
pub signed: bool,
pub metadata: VariableMetadata,
pub packed_dims: Vec<usize>,
}Fields
id: SourceVarIdpath: Vec<String>var_kind: VariableKindsigned: boolmetadata: VariableMetadatapacked_dims: Vec<usize>Per-dimension sizes for the packed shape of the variable.
VariableMetadata::array_dims deliberately only describes unpacked
arrays because that is the source-independent storage shape. The
testbench adapter also needs packed shape for chained selects.