Source-language-independent symbolic lowering and scheduling.
Re-exports
pub use shared::FrontendLookup;pub use shared::FusedSirOptimizationHints;pub use shared::InstancePath;pub use shared::ScheduledRtl;pub use shared::ScheduledRtlOutput;pub use shared::SourceAddr;pub use shared::SourceVarId;pub use shared::VariableInfo;pub use shared::VariableKind;pub use symbolic::flattening;
Modules
Structs
- Frontend
Trace - Optional diagnostics produced while
SymbolicRtlis consumed. - Frontend
Trace Options - Frontend-owned trace switches. Backend and optimizer trace options are intentionally absent from this contract.
- Lowered
Frontend Artifact - Internal artifacts derived from one stable SDK value.
- Source
Location
Enums
Functions
- lower_
frontend_ artifact - Validate and project a stable SDK artifact into Celox symbolic structures.
Type Aliases
- Trace
SimModule - Source-neutral symbolic module retained only when frontend tracing is enabled.